==> was-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/was/mapper/WarToWasUnmanagedServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.mapper;

import com.google.common.collect.Lists;
import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.plugin.was.ci.WarsWebserversVirtualHostMapping;
import com.xebialabs.deployit.plugin.was.ci.WasFileServing;
import com.xebialabs.deployit.plugin.was.ci.WasManagedApacheHttpdServer;
import com.xebialabs.deployit.plugin.was.ci.WasUnmanagedServer;
import com.xebialabs.deployit.plugin.was.ci.WasWarMapping;
import com.xebialabs.deployit.plugin.was.step.*;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Set;

public class WarToWasUnmanagedServerMapper extends JeeWebArtifactToWasTargetMapper<War, WasWarMapping, WasUnmanagedServer> {

	public WarToWasUnmanagedServerMapper(Change<Deployment> change) {
		super(change, false);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(War ear, WasWarMapping mapping, WasUnmanagedServer target, List<Step> steps) {
		Set<WasManagedApacheHttpdServer> webservers = getWebservers(mapping);

		steps.add(new CreateWasVirtualHostStep(target.getCell(), ear.getName()));
		steps.add(new UpdateWasVirtualHostAliasesStep(target.getCell(), ear.getName(), validateAndGetVirtualHostFromMapping(mapping)));
		steps.add(new StopWasUnmanagedServerStep(target));
		steps.add(new StartWasUnmanagedServerStep(target));

		generateDeployStep(ear, mapping, target, webservers, steps);

		// for each Wars inside the Ear , Update File Serving Enabled.
		List<WarsWebserversVirtualHostMapping> fileServingEnabledPerWars = getFileServingEnabledPerWars(mapping);
		for (WarsWebserversVirtualHostMapping warsWebserversVHMapping : fileServingEnabledPerWars) {
			if (warsWebserversVHMapping.getFileServing() != null && warsWebserversVHMapping.getFileServing() != WasFileServing.DO_NOT_OVERRIDE) {
				steps.add(new UpdateWasFileServingEnabledStep(ear, target, warsWebserversVHMapping.getWarName(), warsWebserversVHMapping.getFileServing()));
			}
		}   
		
		for (WasManagedApacheHttpdServer eachWebServer : webservers) {
			associateVirtualHostWithWebServer(virtualHostsPerWebServer, eachWebServer, validateAndGetVirtualHostFromMapping(mapping));
		}
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(War ear, WasWarMapping mapping, WasUnmanagedServer target, List<Step> steps) {
		Set<WasManagedApacheHttpdServer> webservers = getWebservers(mapping);

		generateStopStep(ear, target, mapping, steps);
		generateUndeployStep(ear, target, mapping, steps);

		steps.add(new DestroyWasVirtualHostStep(target.getCell(), ear.getName()));
		steps.add(new StopWasUnmanagedServerStep(target));
		steps.add(new StartWasUnmanagedServerStep(target));

		for (WasManagedApacheHttpdServer eachWebServer : webservers) {
			associateVirtualHostWithWebServer(virtualHostsPerWebServer, eachWebServer, validateAndGetVirtualHostFromMapping(mapping));
		}
	}

	@Override
	protected void generateModificationStepsForModifiedMapping(War oldMappingSource, WasWarMapping oldVersionOfModifiedMapping,
	        WasUnmanagedServer oldMappingTarget, War newMappingSource, WasWarMapping newVersionOfModifiedMapping, WasUnmanagedServer newMappingTarget,
	        List<Step> steps) {

		boolean mappingSourceChanged = !oldMappingSource.equals(newMappingSource);
		Set<WasManagedApacheHttpdServer> webservers = getWebservers(newVersionOfModifiedMapping);

		if (mappingSourceChanged) {
			generateStopStep(oldMappingSource, oldMappingTarget, oldVersionOfModifiedMapping, steps);
			generateUndeployStep(oldMappingSource, oldMappingTarget, oldVersionOfModifiedMapping, steps);
		}

		if (!oldVersionOfModifiedMapping.getVirtualHost().equals(newVersionOfModifiedMapping.getVirtualHost())) {
			steps.add(new StopWasUnmanagedServerStep(oldMappingTarget));
			steps.add(new DestroyWasVirtualHostStep(oldMappingTarget.getCell(), oldMappingSource.getName()));
			steps.add(new CreateWasVirtualHostStep(newMappingTarget.getCell(), newMappingSource.getName()));
			steps.add(new UpdateWasVirtualHostAliasesStep(newMappingTarget.getCell(), newMappingSource.getName(),
			        validateAndGetVirtualHostFromMapping(newVersionOfModifiedMapping)));
			steps.add(new StartWasUnmanagedServerStep(newMappingTarget));
		}

		if (mappingSourceChanged) {
			generateDeployStep(newMappingSource, newVersionOfModifiedMapping, newMappingTarget, webservers, steps);
			// for each Wars inside the Ear , Update File Serving Enabled.
			List<WarsWebserversVirtualHostMapping> fileServingEnabledPerWars = getFileServingEnabledPerWars(newVersionOfModifiedMapping);
			for (WarsWebserversVirtualHostMapping warsWebserversVHMapping : fileServingEnabledPerWars) {
				if (warsWebserversVHMapping.getFileServing() != null && warsWebserversVHMapping.getFileServing() != WasFileServing.DO_NOT_OVERRIDE) {
					steps.add(new UpdateWasFileServingEnabledStep(newMappingSource, newMappingTarget, warsWebserversVHMapping.getWarName(),
					        warsWebserversVHMapping.getFileServing()));
				}
			}
		}
	}

	@Override
	protected void generateDeployStep(War artifact, WasWarMapping mapping, WasUnmanagedServer server, Collection<WasManagedApacheHttpdServer> webservers,
	        List<Step> steps) {
		// vhost name == artifact's name (see generateAdditionStepsForAddedMapping in JeeArtifactToWasClusterMapper)
		steps.add(new WasDeployApplicationStep(server.getCell(), mapping.getArtifact(), Collections.singleton(server), webservers, artifact.getName(), mapping
		        .getSharedLibraries(), mapping.getContextRoot(), mapping.getStartingWeight(), mapping.getClassLoaderMode(), mapping
		        .getResourceEnvironmentEntryReferences(), mapping.getResourceReferences(), mapping.getEjbReferences(), mapping
		        .getSecurityRoleUserGroupMappings()));
	}

	@Override
	protected void generateUndeployStep(War artifact, WasUnmanagedServer cluster, WasWarMapping mapping, List<Step> steps) {
		steps.add(new WasUndeployApplicationStep(cluster.getCell(), mapping.getArtifact()));
	}

	@Override
	protected void generateStartStep(War artifact, WasUnmanagedServer server, WasWarMapping mapping, List<Step> steps) {
		steps.add(new WasStartApplicationStep(server, mapping.getArtifact()));
	}

	@Override
	protected void generateStopStep(War artifact, WasUnmanagedServer server, WasWarMapping mapping, List<Step> steps) {
		steps.add(new WasStopApplicationStep(server, mapping.getArtifact()));
	}

	@Override
	protected String getVirtualHostFromMapping(WasWarMapping mapping) {
		return mapping.getVirtualHost();
	}

	@Override
	public void setDefaults(Deployment d, WasWarMapping m) {
		m.setVirtualHost(d.getVhostDefinition());
		m.setContextRoot(((War) m.getSource()).getName());
	}

	@Override
    protected List<WarsWebserversVirtualHostMapping> getWebserversAndVirtualHostPerWar(WasWarMapping mapping) {
	    return Lists.newArrayList();
    }
	

	@Override
	protected List<WarsWebserversVirtualHostMapping> getFileServingEnabledPerWars(WasWarMapping mapping) {
		List<WarsWebserversVirtualHostMapping> fileServingEnabledPerWars = Lists.newArrayList();
		if (mapping.getFileServing() != null && mapping.getFileServing() != WasFileServing.DO_NOT_OVERRIDE) {
			fileServingEnabledPerWars.add(new WarsWebserversVirtualHostMapping(mapping.getSource().getName() + "." + War.ARCHIVE_EXTENSION, "", "", "", mapping
			        .getFileServing()));
		}
		return fileServingEnabledPerWars;
	}

}

==> was-plugin-1.3.2-sources.jar: com/xebialabs/deployit/plugin/was/mapper/WarToWasUnmanagedServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.mapper;

import com.google.common.collect.Lists;
import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.plugin.was.ci.WarsWebserversVirtualHostMapping;
import com.xebialabs.deployit.plugin.was.ci.WasFileServing;
import com.xebialabs.deployit.plugin.was.ci.WasManagedApacheHttpdServer;
import com.xebialabs.deployit.plugin.was.ci.WasUnmanagedServer;
import com.xebialabs.deployit.plugin.was.ci.WasWarMapping;
import com.xebialabs.deployit.plugin.was.step.*;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Set;

public class WarToWasUnmanagedServerMapper extends JeeWebArtifactToWasTargetMapper<War, WasWarMapping, WasUnmanagedServer> {

	public WarToWasUnmanagedServerMapper(Change<Deployment> change) {
		super(change, false);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(War ear, WasWarMapping mapping, WasUnmanagedServer target, List<Step> steps) {
		Set<WasManagedApacheHttpdServer> webservers = getWebservers(mapping);

		steps.add(new CreateWasVirtualHostStep(target.getCell(), ear.getName()));
		steps.add(new UpdateWasVirtualHostAliasesStep(target.getCell(), ear.getName(), validateAndGetVirtualHostFromMapping(mapping)));
		steps.add(new StopWasUnmanagedServerStep(target));
		steps.add(new StartWasUnmanagedServerStep(target));

		generateDeployStep(ear, mapping, target, webservers, steps);

		// for each Wars inside the Ear , Update File Serving Enabled.
		List<WarsWebserversVirtualHostMapping> fileServingEnabledPerWars = getFileServingEnabledPerWars(mapping);
		for (WarsWebserversVirtualHostMapping warsWebserversVHMapping : fileServingEnabledPerWars) {
			if (warsWebserversVHMapping.getFileServing() != null && warsWebserversVHMapping.getFileServing() != WasFileServing.DO_NOT_OVERRIDE) {
				steps.add(new UpdateWasFileServingEnabledStep(ear, target, warsWebserversVHMapping.getWarName(), warsWebserversVHMapping.getFileServing()));
			}
		}   
		
		for (WasManagedApacheHttpdServer eachWebServer : webservers) {
			associateVirtualHostWithWebServer(virtualHostsPerWebServer, eachWebServer, validateAndGetVirtualHostFromMapping(mapping));
		}
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(War ear, WasWarMapping mapping, WasUnmanagedServer target, List<Step> steps) {
		Set<WasManagedApacheHttpdServer> webservers = getWebservers(mapping);

		generateStopStep(ear, target, mapping, steps);
		generateUndeployStep(ear, target, mapping, steps);

		steps.add(new DestroyWasVirtualHostStep(target.getCell(), ear.getName()));
		steps.add(new StopWasUnmanagedServerStep(target));
		steps.add(new StartWasUnmanagedServerStep(target));

		for (WasManagedApacheHttpdServer eachWebServer : webservers) {
			associateVirtualHostWithWebServer(virtualHostsPerWebServer, eachWebServer, validateAndGetVirtualHostFromMapping(mapping));
		}
	}

	@Override
	protected void generateModificationStepsForModifiedMapping(War oldMappingSource, WasWarMapping oldVersionOfModifiedMapping,
	        WasUnmanagedServer oldMappingTarget, War newMappingSource, WasWarMapping newVersionOfModifiedMapping, WasUnmanagedServer newMappingTarget,
	        List<Step> steps) {

		boolean mappingSourceChanged = !oldMappingSource.equals(newMappingSource);
		Set<WasManagedApacheHttpdServer> webservers = getWebservers(newVersionOfModifiedMapping);

		if (mappingSourceChanged) {
			generateStopStep(oldMappingSource, oldMappingTarget, oldVersionOfModifiedMapping, steps);
			generateUndeployStep(oldMappingSource, oldMappingTarget, oldVersionOfModifiedMapping, steps);
		}

		if (!oldVersionOfModifiedMapping.getVirtualHost().equals(newVersionOfModifiedMapping.getVirtualHost())) {
			steps.add(new StopWasUnmanagedServerStep(oldMappingTarget));
			steps.add(new DestroyWasVirtualHostStep(oldMappingTarget.getCell(), oldMappingSource.getName()));
			steps.add(new CreateWasVirtualHostStep(newMappingTarget.getCell(), newMappingSource.getName()));
			steps.add(new UpdateWasVirtualHostAliasesStep(newMappingTarget.getCell(), newMappingSource.getName(),
			        validateAndGetVirtualHostFromMapping(newVersionOfModifiedMapping)));
			steps.add(new StartWasUnmanagedServerStep(newMappingTarget));
		}

		if (mappingSourceChanged) {
			generateDeployStep(newMappingSource, newVersionOfModifiedMapping, newMappingTarget, webservers, steps);
			// for each Wars inside the Ear , Update File Serving Enabled.
			List<WarsWebserversVirtualHostMapping> fileServingEnabledPerWars = getFileServingEnabledPerWars(newVersionOfModifiedMapping);
			for (WarsWebserversVirtualHostMapping warsWebserversVHMapping : fileServingEnabledPerWars) {
				if (warsWebserversVHMapping.getFileServing() != null && warsWebserversVHMapping.getFileServing() != WasFileServing.DO_NOT_OVERRIDE) {
					steps.add(new UpdateWasFileServingEnabledStep(newMappingSource, newMappingTarget, warsWebserversVHMapping.getWarName(),
					        warsWebserversVHMapping.getFileServing()));
				}
			}
		}
	}

	@Override
	protected void generateDeployStep(War artifact, WasWarMapping mapping, WasUnmanagedServer server, Collection<WasManagedApacheHttpdServer> webservers,
	        List<Step> steps) {
		// vhost name == artifact's name (see generateAdditionStepsForAddedMapping in JeeArtifactToWasClusterMapper)
		steps.add(new WasDeployApplicationStep(server.getCell(), mapping.getSource(), Collections.singleton(server), webservers, artifact.getName(), mapping
		        .getSharedLibraries(), mapping.getContextRoot(), mapping.getStartingWeight(), mapping.getClassLoaderMode(), mapping
		        .getResourceEnvironmentEntryReferences(), mapping.getResourceReferences(), mapping.getEjbReferences(), mapping
		        .getSecurityRoleUserGroupMappings()));
	}

	@Override
	protected void generateUndeployStep(War artifact, WasUnmanagedServer cluster, WasWarMapping mapping, List<Step> steps) {
		steps.add(new WasUndeployApplicationStep(cluster.getCell(), mapping.getSource()));
	}

	@Override
	protected void generateStartStep(War artifact, WasUnmanagedServer server, WasWarMapping mapping, List<Step> steps) {
		steps.add(new WasStartApplicationStep(server, mapping.getSource()));
	}

	@Override
	protected void generateStopStep(War artifact, WasUnmanagedServer server, WasWarMapping mapping, List<Step> steps) {
		steps.add(new WasStopApplicationStep(server, mapping.getSource()));
	}

	@Override
	protected String getVirtualHostFromMapping(WasWarMapping mapping) {
		return mapping.getVirtualHost();
	}

	@Override
	public void setDefaults(Deployment d, WasWarMapping m) {
		m.setVirtualHost(d.getVhostDefinition());
		m.setContextRoot(((War) m.getSource()).getName());
	}

	@Override
    protected List<WarsWebserversVirtualHostMapping> getWebserversAndVirtualHostPerWar(WasWarMapping mapping) {
	    return Lists.newArrayList();
    }
	

	@Override
	protected List<WarsWebserversVirtualHostMapping> getFileServingEnabledPerWars(WasWarMapping mapping) {
		List<WarsWebserversVirtualHostMapping> fileServingEnabledPerWars = Lists.newArrayList();
		if (mapping.getFileServing() != null && mapping.getFileServing() != WasFileServing.DO_NOT_OVERRIDE) {
			fileServingEnabledPerWars.add(new WarsWebserversVirtualHostMapping(mapping.getSource().getName() + "." + War.ARCHIVE_EXTENSION, "", "", "", mapping
			        .getFileServing()));
		}
		return fileServingEnabledPerWars;
	}

}
